## Metadata_Start 
## code: en
## title: About this Guide 
## slug: about-this-guide 
## seoTitle: About this Guide 
## description:  
## contentType: Markdown 
## Metadata_End

This user guide is updated continuously. Everyone should read the interface overview article, especially to learn how to manipulate FontLab's panels and dialogs, and understand the difference between tapping and holding keys for tool shortcuts.

The first chapters demonstrate FontLab 7 usage. They're organized in logical learning order, though you can navigate using the links in any sequence. The final chapters serve as references describing all tools and commands, interface controls, and typographic terms and technologies.

The manual concludes with a collection of tutorials. While the core manual explains FontLab 7 functionality, the tutorials show practical applications and techniques you might not discover on your own. We plan to expand this section with additional tutorials.

See the complete list of Keyboard Shortcuts and instructions for Customizing Shortcuts.